#!/usr/bin/env python

import unittest
import smbc
import settings

class TestContext(unittest.TestCase):
    def setUp(self):
        self.ctx = smbc.Context()

    def tearDown(self):
        del self.ctx

    def testWorkgroup(self):
        list = self.ctx.opendir('smb://').getdents()
        assert(len(list) > 0)
        for entry in list:
            assert(entry.smbc_type == 1)

    def testServer(self):
        uri = 'smb://' + settings.WORKGROUP
        list = self.ctx.opendir(uri).getdents()
        assert(len(list) > 0)
        for entry in list:
            assert(entry.smbc_type == 2)

    def testShare(self):
        uri = 'smb://' + settings.SERVER
        list = self.ctx.opendir(uri).getdents()
        assert(len(list) > 0)
        for entry in list:
            assert(entry.smbc_type == 3 or entry.smbc_type == 6)

if __name__ == '__main__':
    unittest.main()



#!/usr/bin/env python

import unittest
import smbc
import settings

class TestAuth(unittest.TestCase):
    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testNoAutoAnonymousLogin(self):
        ctx = smbc.Context()
        ctx.optionNoAutoAnonymousLogin = True
        uri = 'smb://' + settings.SERVER
        try:
            dir = ctx.opendir(uri)
        except smbc.PermissionError:
            pass
        except:
            self.fail()
        else:
            self.fail()

    def callback(self, server, share, workgroup, username, password):
        return (workgroup, settings.USERNAME, settings.PASSWORD)

    def testAuth(self):
        ctx = smbc.Context()
        ctx.optionNoAutoAnonymousLogin = True
        cb = lambda se, sh, w, u, p: (w, settings.USERNAME, settings.PASSWORD)
        ctx.functionAuthData = cb
        uri = 'smb://' + settings.SERVER
        try:
            dir = ctx.opendir(uri)
        except:
            self.fail()

    def testAuthFail(self):
        ctx = smbc.Context()
        ctx.optionNoAutoAnonymousLogin = True
        cb = lambda se, sh, w, u, p: (w, settings.USERNAME, "")
        ctx.functionAuthData = cb
        uri = 'smb://' + settings.SERVER
        try:
            dir = ctx.opendir(uri)
        except smbc.PermissionError:
            pass
        except:
            self.fail()
        else:
            self.fail()

if __name__ == '__main__':
    unittest.main()



from distutils.core import setup, Extension
setup (name="pysmbc",
       version="1.0.7",
       description="Python bindings for libsmbclient",
       author="Tim Waugh",
       author_email="twaugh@redhat.com",
       maintainer="Tim Waugh",
       maintainer_email="twaugh@redhat.com",
       url="http://cyberelk.net/tim/software/pysmbc/",
       download_url="http://cyberelk.net/tim/data/pysmbc/",
       classifiers=[
        "Intended Audience :: Developers",
        "Topic :: Software Development :: Libraries :: Python Modules",
        "License :: OSI Approved :: GNU General Public License (GPL)",
        "Development Status :: 5 - Production/Stable",
        "Operating System :: Unix",
        "Programming Language :: C",
        ],
       license="GPLv2+",
       ext_modules=[Extension("smbc",
                              ["smbcmodule.c",
                               "context.c",
                               "dir.c",
                               "file.c",
                               "smbcdirent.c"],
                              libraries=["smbclient"])])
